/*
 * @(#)SCAuthTool.hxx	1.00 10th June 2000
 * 
 * Functions that take care of user authorization and security features
 * of smart cards.
 *
 * Modification Log:
 */

/**
 *
 * SCTool is a sample application using Schlumberger PayFlex 1K smart cards.
 * Using this application you can personalize a card, and store data either
 * protected with a pin number or without protection, as you desire.
 * 
 * Several generic functions have been written for SmartCards, so that they
 * can be ported later to any type of SmartCard. 
 * 
 * For more information on SmartCards and how to program them, refer to the
 * "Smart Card Crash Course" at my website: 
 * http://tanmaykm.tripod.com.
 *
 * You are free to use this code and to make modifications provided
 * this notice is retained.
 * <p>
 * If you found this useful, please add a note of acknowledgement to my guestbook,
 * or send me a mail at <a href="mailto:tanmaykm@hotmail.com">tanmaykm@hotmail.com</a>. 
 * If you would like to report a bug or suggest some improvements, 
 * you are most welcome. I will be happy to help you use this piece of code.
 * <p>
 *
 * @author 	    Tanmay K. Mohapatra
 * @version     1.00, 10th June, 2000
 */

#ifndef SCAUTHTOOL_HXX
#define SCAUTHTOOL_HXX

#include <windows.h>
#include <winscard.h>
#include <scarderr.h>

int VerifyKey(SCARDHANDLE hCardHandle, int iIsCHVPin, BYTE *pKey, BYTE KeyLen, BYTE *RecvStatus, long *pRet);
int VerifyKeyAndCheckErr(SCARDHANDLE hCard, int iIsCHVPin, BYTE *pKey, BYTE KeyLen, char *sMessage);

int ChangeKeyAndCheckErr(SCARDHANDLE hCard, int iIsCHVPin, BYTE *pOldKey, BYTE *pNewKey, char *sMessage);
int ChangeKey(SCARDHANDLE hCardHandle, int iIsCHVPin, BYTE *pOldKey, BYTE *pNewKey, BYTE *RecvStatus, long *pRet);

int UnblockKeyAndCheckErr(SCARDHANDLE hCard, BYTE *pKey, char *sMessage);
int UnblockKey(SCARDHANDLE hCardHandle, BYTE *pKey, BYTE *RecvStatus, long *pRet);

int GetChallenge(SCARDHANDLE hCardHandle, BYTE *Challenge, BYTE *RecvStatus, long *pRet);
int SendExtAuthToCard(SCARDHANDLE hCardHandle, BYTE KeyNumber, BYTE *Challenge, BYTE *RecvStatus, long *pRet);

int SendIntAuthToCard(SCARDHANDLE hCardHandle, BYTE KeyNumber, BYTE *Challenge, BYTE *RecvStatus, long *pRet);
int GetResponse(SCARDHANDLE hCardHandle, BYTE *Data, BYTE DataLen, BYTE *RecvStatus, long *pRet);

int ExternalAuthentication(SCARDHANDLE hCardHandle, BYTE KeyNumber, BYTE *ExtKey, char *sMessage);
int InternalAuthentication(SCARDHANDLE hCardHandle, BYTE KeyNumber, BYTE *IntKey, char *sMessage);

int InternalAuth();
int ExternalAuth();

#endif /* SCAUTHTOOL_HXX */
