/*
 * @(#)SCConnectTool.hxx	1.00 10th June 2000
 * 
 * Functions that take care of connecting to a card reader and accessing
 * the card. Since these functions are written using PC/SC APIs, they will
 * work for any PC/SC compliant smartcard reader.
 *
 * Modification Log:
 */

/**
 *
 * SCTool is a sample application using Schlumberger PayFlex 1K smart cards.
 * Using this application you can personalize a card, and store data either
 * protected with a pin number or without protection, as you desire.
 * 
 * Several generic functions have been written for SmartCards, so that they
 * can be ported later to any type of SmartCard. 
 * 
 * For more information on SmartCards and how to program them, refer to the
 * "Smart Card Crash Course" at my website: 
 * http://tanmaykm.tripod.com.
 *
 * You are free to use this code and to make modifications provided
 * this notice is retained.
 * <p>
 * If you found this useful, please add a note of acknowledgement to my guestbook,
 * or send me a mail at <a href="mailto:tanmaykm@hotmail.com">tanmaykm@hotmail.com</a>. 
 * If you would like to report a bug or suggest some improvements, 
 * you are most welcome. I will be happy to help you use this piece of code.
 * <p>
 *
 * @author 	    Tanmay K. Mohapatra
 * @version     1.00, 10th June, 2000
 */

#ifndef SCCONNECTTOOL_HXX
#define SCCONNECTTOOL_HXX

#include <windows.h>
#include <winscard.h>
#include <scarderr.h>

typedef struct 
{
	LPBYTE	pATR;		//SCARD_ATTR_ATR_STRING Answer to reset (ATR) string. 
	unsigned long lATRLen;

	LPBYTE	pChannel;
	int		iChannelLen;

	DWORD	dwSpecialFacilities;

	LPBYTE	pVendorName;
	unsigned long	lVendorNameLen;
} SCTOOL_READER_CHARACTERISTICS;

int ConnectCard(SCARDCONTEXT *phSC, SCARDHANDLE *phCardHandle, char *sReader, char *sCard, long *plSysErr);
int DisconnectCard(SCARDCONTEXT *phSC, SCARDHANDLE *phCardHandle, long *plSysErr);
int GetReadersList(SCARDCONTEXT hSC, char sList[20][160], int *piCount);
int ChooseReader(SCARDCONTEXT hSC, SCARDHANDLE *pCardHandle, char *sReader, char *sCard,  long *plSysErr);

int GetResponse(SCARDHANDLE hCardHandle, BYTE *Data, BYTE DataLen, BYTE *RecvStatus, long *pRet);

int PrintCardUsageInfo(SCARDHANDLE hCardHandle, char *sMessage);
void GetReaderCharacteristics(SCARDHANDLE hCardHandle, SCTOOL_READER_CHARACTERISTICS *pstReader);
void FreeReaderCharacteristics(SCARDCONTEXT hSC, SCTOOL_READER_CHARACTERISTICS *pstReader);
int PrintReaderCharacteristics(SCARDCONTEXT hSC, SCARDHANDLE hCardHandle);

#endif /*  SCCONNECTTOOL_HXX */
