/*
 * @(#)SCFileTool.hxx	1.00 10th June 2000
 * 
 * Functions that take care of creating, reading and writing files into
 * a smartcard filesystem.
 *
 * Modification Log:
 */

/**
 *
 * SCTool is a sample application using Schlumberger PayFlex 1K smart cards.
 * Using this application you can personalize a card, and store data either
 * protected with a pin number or without protection, as you desire.
 * 
 * Several generic functions have been written for SmartCards, so that they
 * can be ported later to any type of SmartCard. 
 * 
 * For more information on SmartCards and how to program them, refer to the
 * "Smart Card Crash Course" at my website: 
 * http://tanmaykm.tripod.com.
 *
 * You are free to use this code and to make modifications provided
 * this notice is retained.
 * <p>
 * If you found this useful, please add a note of acknowledgement to my guestbook,
 * or send me a mail at <a href="mailto:tanmaykm@hotmail.com">tanmaykm@hotmail.com</a>. 
 * If you would like to report a bug or suggest some improvements, 
 * you are most welcome. I will be happy to help you use this piece of code.
 * <p>
 *
 * @author 	    Tanmay K. Mohapatra
 * @version     1.00, 10th June, 2000
 */

#ifndef SCFILETOOL_HXX
#define SCFILETOOL_HXX

#include <windows.h>
#include <winscard.h>
#include <scarderr.h>

// Generic operations
int SelectFile(SCARDHANDLE hCardHandle, BYTE *fileId, BYTE *RecvStatus, long *pRet);
int SelectFileAndCheckErr(SCARDHANDLE hCardHandle, BYTE *fileId, char *sMsg);

// DF operations
int CreateDFAndCheckErr(SCARDHANDLE hCard, BYTE *fileId, BYTE *FileSize, BYTE *AccessCond, BYTE *KeyNum, char *sMessage);
int CreateDFile(SCARDHANDLE hCardHandle, BYTE *fileId, BYTE *FileSize, BYTE *AccessCond, BYTE *KeyNum, BYTE *RecvStatus, long *pRet);

// EF operations
int CreateEFAndCheckErr(SCARDHANDLE hCard, BYTE *fileId, BYTE *FileSize, BYTE *AccessCond, BYTE *KeyNum, BYTE RecLen, BYTE FileType, char *sMessage);
int CreateEFFile(SCARDHANDLE hCardHandle, BYTE *fileId, BYTE *FileSize, BYTE *AccessCond, BYTE *KeyNum, BYTE RecLen, BYTE FileType, BYTE *RecvStatus, long *pRet);

int WriteEFRecAndCheckErr(SCARDHANDLE hCard, BYTE *FileData, BYTE DataLen, char *sMessage);
int WriteEFRec(SCARDHANDLE hCardHandle, BYTE *FileData, BYTE DataLen, BYTE *RecvStatus, long *pRet);

int UpdateEFRecAndCheckErr(SCARDHANDLE hCard, BYTE *FileData, BYTE DataLen, BYTE RecNum, char *sMessage);
int UpdateEFRec(SCARDHANDLE hCardHandle, BYTE *FileData, BYTE DataLen, BYTE RecNum, BYTE *RecvStatus, long *pRet);

int ReadEFRecAndCheckErr(SCARDHANDLE hCard, BYTE *FileData, BYTE DataLen, BYTE RecNum, char *sMessage);
int ReadEFRec(SCARDHANDLE hCardHandle, BYTE *FileData, BYTE DataLen, BYTE RecNum, BYTE *RecvStatus, long *pRet);

// ETF operations
int CreateETFAndCheckErr(SCARDHANDLE hCard, BYTE *fileId, BYTE *FileSize, BYTE *AccessCond, BYTE *KeyNum, char *sMessage);
int CreateETFile(SCARDHANDLE hCardHandle, BYTE *fileId, BYTE *FileSize, BYTE *AccessCond, BYTE *KeyNum, BYTE *RecvStatus, long *pRet);

int WriteETFAndCheckErr(SCARDHANDLE hCard, BYTE *FileData, BYTE DataLen, char *sMessage);
int WriteETFile(SCARDHANDLE hCardHandle, BYTE *FileData, BYTE DataLen, BYTE *RecvStatus, long *pRet);

int ReadETFAndCheckErr(SCARDHANDLE hCard, BYTE *FileData, BYTE DataLen, char *sMessage);
int ReadETFile(SCARDHANDLE hCardHandle, BYTE *FileData, BYTE DataLen, BYTE *RecvStatus, long *pRet);

#endif /* SCFILETOOL_HXX */
