/*
 * @(#)SCToolTest.java	1.00 10th June 2000
 * 
 * Contains a character screen menu based interface to the tool.
 *
 * Modification Log:
 */

/**
 *
 * SCTool is a sample application using Schlumberger PayFlex 1K smart cards.
 * Using this application you can personalize a card, and store data either
 * protected with a pin number or without protection, as you desire.
 * 
 * Several generic functions have been written for SmartCards, so that they
 * can be ported later to any type of SmartCard. 
 * 
 * For more information on SmartCards and how to program them, refer to the
 * "Smart Card Crash Course" at my website: 
 * http://tanmaykm.tripod.com.
 *
 * You are free to use this code and to make modifications provided
 * this notice is retained.
 * <p>
 * If you found this useful, please add a note of acknowledgement to my guestbook,
 * or send me a mail at <a href="mailto:tanmaykm@hotmail.com">tanmaykm@hotmail.com</a>. 
 * If you would like to report a bug or suggest some improvements, 
 * you are most welcome. I will be happy to help you use this piece of code.
 * <p>
 *
 * @author 	    Tanmay K. Mohapatra
 * @version     1.00, 10th June, 2000
 */


#include <stdio.h>
#include <string.h>
#include "SCConnectTool.hxx"
#include "SCMessageTool.hxx"
#include "SCFileTool.hxx"
#include "SCAuthTool.hxx"
#include "SCApplication.hxx"

int main(void)
{
	int iOption;
	unsigned char sData[MAX_USER_INFO_SIZE], sVerifyData[MAX_USER_INFO_SIZE], sPin[16], sNewPin[16];
	char sUserId[32], sPassword[32], sLang[32];
	BYTE DataLen;
	char sMessage[1024];

	do
	{
		printf(
			"\nOptions:\n"
			"1. Read plain user info card\n"
			"2. Read user info card with pin\n"
			"3. Update plain user info card\n"
			"4. Update user info card with pin\n"
			"5. Make plain user info card (*)\n"
			"6. Make user info card with pin (*)\n"
			"7. Change pin\n"
			"8. Unblock pin\n"
			"0. Exit\n"
			"Enter Choice: ");
		fflush(stdin); fflush(stdout);
		scanf("%d", &iOption);

		switch(iOption)
		{
			case 0:
				break;

			case 1:
				*sData = 0;
				DataLen = MAX_USER_INFO_SIZE;
				if(0 != AccessPlainUserCard(READ_MODE, sData, DataLen, sMessage))
				{
					printf("Error: %s.\n", sMessage);
					break;
				}
				sscanf((char *)sData, "%s%s%s", sUserId, sPassword, sLang);
				printf("%s %s %s\n", sUserId, sPassword, sLang);
				break;

			case 2:
				printf("Enter Pin: ");
				fflush(stdout); fflush(stdin);
				scanf("%s", sPin);

				*sData = 0;
				DataLen = MAX_USER_INFO_SIZE;
				if(0 != AccessPinUserCard(READ_MODE, sData, DataLen, sPin, sMessage))
				{
					printf("Error: %s.\n", sMessage);
					break;
				}
				sscanf((char *)sData, "%s%s%s", sUserId, sPassword, sLang);
				printf("%s %s %s\n", sUserId, sPassword, sLang);
				break;

			case 3:
				printf("Enter Old USERID PASSWORD LANG: ");
				fflush(stdout); fflush(stdin);
				scanf("%s%s%s", sUserId, sPassword, sLang);

				// read card and verify
				*sData = 0;
				*sVerifyData = 0;
				DataLen = MAX_USER_INFO_SIZE;
				if(0 != AccessPlainUserCard(READ_MODE, sData, DataLen, sMessage))
				{
					printf("Error: %s.\n", sMessage);
					break;
				}
				sprintf((char *)sVerifyData, "%s %s %s", sUserId, sPassword, sLang);
				if(strcmp((char*)sData, (char*)sVerifyData))
				{
					printf("Sorry. Incorrect user information.\n");
					break;
				}

				// get new data and write
				printf("Enter New USERID PASSWORD LANG: ");
				fflush(stdout); fflush(stdin);
				scanf("%s%s%s", sUserId, sPassword, sLang);
				sprintf((char *)sData, "%s %s %s", sUserId, sPassword, sLang);
				DataLen = strlen((char *)sData) + 1;
				if(0 != AccessPlainUserCard(WRITE_MODE, sData, DataLen, sMessage))
				{
					printf("Error: %s.\n", sMessage);
					break;
				}
				printf("Updated User Data: [%s]\n", sData);
				break;

			case 4:
				printf("Enter Pin: ");
				fflush(stdout); fflush(stdin);
				scanf("%s", sPin);

				// get new data and write
				printf("Enter New USERID PASSWORD LANG PIN: ");
				fflush(stdout); fflush(stdin);
				scanf("%s%s%s%s", sUserId, sPassword, sLang, sNewPin);
				sprintf((char *)sData, "%s %s %s", sUserId, sPassword, sLang);
				DataLen = strlen((char *)sData) + 1;
				if(0 != AccessPinUserCard(WRITE_MODE, sData, DataLen, sPin, sMessage))
				{
					printf("Error: %s.\n", sMessage);
					break;
				}
				printf("Updated User Data: [%s]\n", sData);
				printf("Pin update not yet implemented\n");
				break;

			case 5:
				*sData = 0;
				printf("Enter USERID PASSWORD LANG: ");
				fflush(stdout); fflush(stdin);
				scanf("%s%s%s", sUserId, sPassword, sLang);
				sprintf((char *)sData, "%s %s %s", sUserId, sPassword, sLang);
				DataLen = strlen((char *)sData) + 1;
				if(0 != AccessPlainUserCard(CREATE_MODE, sData, DataLen, sMessage))
				{
					printf("Error: %s.\n", sMessage);
					break;
				}
				printf("Created User Data: [%s]\n", sData);
				break;
			case 6:
				*sData = 0;
				printf("Enter USERID PASSWORD LANG PIN: ");
				fflush(stdout); fflush(stdin);
				scanf("%s%s%s%s", sUserId, sPassword, sLang, sPin);
				sprintf((char *)sData, "%s %s %s", sUserId, sPassword, sLang);
				DataLen = strlen((char *)sData) + 1;
				if(0 != AccessPinUserCard(CREATE_MODE, sData, DataLen, sPin, sMessage))
				{
					printf("Error: %s.\n", sMessage);
					break;
				}
				printf("Created User Data: [%s] with Pin:[%s]\n", sData, sPin);
				break;
			case 7:
				*sData = 0;
				printf("Enter Old PIN: ");
				fflush(stdout); fflush(stdin);
				scanf("%s", sPin);
				printf("Enter New PIN: ");
				fflush(stdout); fflush(stdin);
				scanf("%s", sNewPin);
				if(0 != ChangePinInUserCard(sPin, sNewPin, sMessage))
				{
					printf("Error: %s.\n", sMessage);
					break;
				}
				printf("Changed Pin\n");
				break;
			case 8:
				*sData = 0;
				printf("Enter PIN: ");
				fflush(stdout); fflush(stdin);
				scanf("%s", sPin);
				if(0 != UnblockPinUserCard(sPin, sMessage))
				{
					printf("Error: %s.\n", sMessage);
					break;
				}
				printf("Unblocked Pin\n");
				break;
			default:
				printf("Invalid option %d\n", iOption);
				break;
		}
	} while(iOption != 0);

	return 0;
}

